@@ -62,11 +62,13 @@ import logging
 import random
 import time
 
+import requests.exceptions
 import six
 
 from google.api_core import datetime_helpers
 from google.api_core import exceptions
 from google.api_core import general_helpers
+from google.auth import exceptions as auth_exceptions
 
 _LOGGER = logging.getLogger(__name__)
 _DEFAULT_INITIAL_DELAY = 1.0  # seconds
@@ -101,6 +103,9 @@ if_transient_error = if_exception_type(
     exceptions.InternalServerError,
     exceptions.TooManyRequests,
     exceptions.ServiceUnavailable,
+    requests.exceptions.ConnectionError,
+    requests.exceptions.ChunkedEncodingError,
+    auth_exceptions.TransportError,
 )
 """A predicate that checks if an exception is a transient API error.
 
@@ -125,9 +130,9 @@ def exponential_sleep_generator(initial, maximum, multiplier=_DEFAULT_DELAY_MULT
         https://cloud.google.com/storage/docs/exponential-backoff
 
     Args:
-        initial (float): The minimum amout of time to delay. This must
+        initial (float): The minimum amount of time to delay. This must
             be greater than 0.
-        maximum (float): The maximum amout of time to delay.
+        maximum (float): The maximum amount of time to delay.
         multiplier (float): The multiplier applied to the delay.
 
     Yields:
@@ -230,9 +235,9 @@ class Retry(object):
     Args:
         predicate (Callable[Exception]): A callable that should return ``True``
             if the given exception is retryable.
-        initial (float): The minimum a,out of time to delay in seconds. This
+        initial (float): The minimum amount of time to delay in seconds. This
             must be greater than 0.
-        maximum (float): The maximum amout of time to delay in seconds.
+        maximum (float): The maximum amount of time to delay in seconds.
         multiplier (float): The multiplier applied to the delay.
         deadline (float): How long to keep retrying in seconds. The last sleep
             period is shortened as necessary, so that the last retry runs at
@@ -288,6 +293,10 @@ class Retry(object):
 
         return retry_wrapped_func
 
+    @property
+    def deadline(self):
+        return self._deadline
+
     def with_deadline(self, deadline):
         """Return a copy of this retry with the given deadline.
 
@@ -329,9 +338,9 @@ class Retry(object):
         """Return a copy of this retry with the given delay options.
 
         Args:
-            initial (float): The minimum amout of time to delay. This must
+            initial (float): The minimum amount of time to delay. This must
                 be greater than 0.
-            maximum (float): The maximum amout of time to delay.
+            maximum (float): The maximum amount of time to delay.
             multiplier (float): The multiplier applied to the delay.
 
         Returns:
@@ -341,7 +350,7 @@ class Retry(object):
             predicate=self._predicate,
             initial=initial if initial is not None else self._initial,
             maximum=maximum if maximum is not None else self._maximum,
-            multiplier=multiplier if maximum is not None else self._multiplier,
+            multiplier=multiplier if multiplier is not None else self._multiplier,
             deadline=self._deadline,
             on_error=self._on_error,
         )
